#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-4FHvjgQdmkX1SB3Z63DtGD
key:                  dhall-1.42.3-4FHvjgQdmkX1SB3Z63DtGD
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  d63c47043d65980c55557291853c03cd
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-4FHvjgQdmkX1SB3Z63DtGD
depends:
    Diff-0.5-A74QtznqER993QsREhG7c9
    aeson-2.2.2.0-6c1DCPq2cjw7mSOIGM724W
    aeson-pretty-0.8.10-FzHF9GoXKHa6sey9IGLZM9
    ansi-terminal-1.1-4r9UE8W85hy3ofo15nhM3F
    atomic-write-0.2.1.1-EW3s2Hg1Z83BmuqIEwWAuM base-4.18.2.1
    base16-bytestring-1.0.2.0-Kn1heJ4eFku33azk8Re0oa
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4uVw9MDvZ5oAae1xp3bqUp
    cborg-0.2.10.0-Ha9yT8sguHp4inckP9qSGb
    cborg-json-0.2.6.0-6lqWSGFJqpOeZYsiEPOmb containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-3bdwpRoBTXh1Za0eRFU4Zm
    data-fix-0.3.4-Bq90a19aXvlOhGT2xDinh deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-7005ZDlwAbLGuISDQOkNkn exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-K5Jv429g4FFKan5L8mlmT2
    hashable-1.4.7.0-29C6HO1kEzxKGOntKCwjk4 haskeline-0.8.2.1
    http-client-0.7.19-5ssHakQzOHODxkRAhbUNfr
    http-client-tls-0.3.6.4-9qZl85bdUY1LG6630xexvr
    http-types-0.12.4-EOP8M0z2aoj67cPO54IyNv
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-IyIXZKwr5ZfHxobaweF1bw
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-Dqmf2XZhpKk16ZGQymmkCW
    optparse-applicative-0.18.1.0-BxGWYUUmFSvAWQPaHpJkSX
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-DITnP6X1XI58dGVYmGX0ES
    pretty-simple-4.1.4.0-1bmjuQT2HOC3yXXRZlHKfF
    prettyprinter-1.7.1-H2rJD2WExIbcRy2n74kLf
    prettyprinter-ansi-terminal-1.1.4-17QDQnvgM0PL8GivpLJq8k
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-DFmvyClKolsDKaqDO41mzB
    serialise-0.2.6.1-7usJclZvBfQG2DRC49S6b6 template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-8cbjQf76r8z623JXqeFlHE
    text-short-0.1.6.1-9GbJ0HLDhy5Ixzw88HTz2K
    th-lift-instances-0.1.20-1ATFVjBOjSvKI1WGPl2wvi time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-5rXwzu0vMWVWC5G5Ppx8z
    unordered-containers-0.2.20.1-Hsa9d2Ja6XgAATZt7ZTK9f
    vector-0.13.2.0-CQhR7DRX3H037jPZymXmiQ

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

